var namespace_v_s_t_g_u_i_1_1_standalone =
[
    [ "Application", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_application.html", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_application" ],
    [ "Async", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_async.html", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_async" ],
    [ "CommandGroup", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html", [
      [ "Application", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html#a3e27afa829309036a28ce2a244a78f1f", null ],
      [ "Debug", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html#aaa475c48528c03cff70e6dc070bf1406", null ],
      [ "Edit", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html#afb4c8ad76575fc534fda92ec0cc745dd", null ],
      [ "File", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html#afabe2b64abb8dc52de8b8b3e58f6da90", null ],
      [ "Window", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html#a79585c5cb7c654296b158b6d480873e9", null ]
    ] ],
    [ "CommandName", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html", [
      [ "About", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#ab7f8c189c4daa1c6180f7a918ddaae42", null ],
      [ "CloseWindow", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a5621277531a26e2a9e3c6fc94f6045d1", null ],
      [ "Copy", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a090badc6f06112d958c3e9543fdcd8fb", null ],
      [ "Cut", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a285c438e7aaa3eea4da618e49ecd235b", null ],
      [ "Delete", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aeec45f7e4c1b9cfd7df8aae27d23aa29", null ],
      [ "FindNext", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#adbcf8817b4827f98d018a74ac657ac69", null ],
      [ "FindPrevious", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aa37300678f4e547bf98ce3b1dbdbe801", null ],
      [ "Help", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a86dea344e9429aa10bd79fe8faf7d6c1", null ],
      [ "MenuSeparator", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a4862aa9abe601fcab28aafa661efaeaf", null ],
      [ "New", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#ac8e97ffc79a9b7f51ddb6f9001d44eb6", null ],
      [ "Open", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#afcca78548650ce3bc0fad34b395cab03", null ],
      [ "Paste", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a7a3c9b00144ef8e4163f9738ecdaaffd", null ],
      [ "Preferences", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a9247f47b642b9f7a737a6a56d25228fa", null ],
      [ "Quit", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aaebedacd311787d028489d8feac24c71", null ],
      [ "RecreateView", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a0e02ec3e4445c30e4b76ba0dceee6529", null ],
      [ "Redo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#adc40ead4f2201564cc3eeeb1f2905640", null ],
      [ "ResaveSharedResources", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#abf8380ec42326587b3029af2175b1d6c", null ],
      [ "Revert", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a7be1047d27e4db13b3b2066f76a93c72", null ],
      [ "Save", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a1e9821c4955185cbd77f5bf6acf53cfe", null ],
      [ "SaveAs", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#aabbb135ceee8c86aaeb3201a9bbc88b0", null ],
      [ "SelectAll", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a11d389e1fa82f6f4130eea8cdfd5fbd7", null ],
      [ "ToggleInlineUIEditor", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#addce384386212d29a5aebf581f7202a2", null ],
      [ "Undo", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html#a3f33e4ad91eb8945eb36c0a3e2b8b409", null ]
    ] ],
    [ "Commands", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands" ],
    [ "UIDesc", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc" ],
    [ "Value", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_value.html", "namespace_v_s_t_g_u_i_1_1_standalone_1_1_value" ],
    [ "AlertBoxConfig", "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config.html", "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config" ],
    [ "AlertBoxForWindowConfig", "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_for_window_config.html", "struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_for_window_config" ],
    [ "Command", "struct_v_s_t_g_u_i_1_1_standalone_1_1_command.html", "struct_v_s_t_g_u_i_1_1_standalone_1_1_command" ],
    [ "IApplication", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_application.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_application" ],
    [ "ICommandHandler", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_command_handler.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_command_handler" ],
    [ "ICommonDirectories", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_common_directories.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_common_directories" ],
    [ "IMenuBuilder", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder" ],
    [ "IMutableStepValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_mutable_step_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_mutable_step_value" ],
    [ "IPreference", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_preference.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_preference" ],
    [ "IRangeValueConverter", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_range_value_converter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_range_value_converter" ],
    [ "ISharedUIResources", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_shared_u_i_resources.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_shared_u_i_resources" ],
    [ "IStepValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_step_value" ],
    [ "IStringListValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_list_value" ],
    [ "IStringValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_string_value" ],
    [ "IUIDescWindowController", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_u_i_desc_window_controller" ],
    [ "IValue", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value" ],
    [ "IValueConverter", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_converter" ],
    [ "IValueListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_value_listener" ],
    [ "IWindow", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window" ],
    [ "IWindowController", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window_controller.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window_controller" ],
    [ "IWindowListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window_listener.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_i_window_listener" ],
    [ "MenuBuilderAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_menu_builder_adapter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_menu_builder_adapter" ],
    [ "NoMenuBuilder", "class_v_s_t_g_u_i_1_1_standalone_1_1_no_menu_builder.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_no_menu_builder" ],
    [ "Preferences", "class_v_s_t_g_u_i_1_1_standalone_1_1_preferences.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_preferences" ],
    [ "ValueListenerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_value_listener_adapter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_value_listener_adapter" ],
    [ "WindowClosedListener", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_closed_listener.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_closed_listener" ],
    [ "WindowConfiguration", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_configuration.html", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_configuration" ],
    [ "WindowControllerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_controller_adapter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_controller_adapter" ],
    [ "WindowListenerAdapter", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter.html", "class_v_s_t_g_u_i_1_1_standalone_1_1_window_listener_adapter" ],
    [ "WindowStyle", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_style.html", "struct_v_s_t_g_u_i_1_1_standalone_1_1_window_style" ],
    [ "PlatformFrameConfigPtr", "namespace_v_s_t_g_u_i_1_1_standalone.html#ab11a0e1b09cdba1e98eab113ebd5eb0a", null ],
    [ "ValueConverterPtr", "namespace_v_s_t_g_u_i_1_1_standalone.html#acb13d531f32416d3ba0b85e8f8237468", null ],
    [ "ValuePtr", "namespace_v_s_t_g_u_i_1_1_standalone.html#af94fa214cf707a169d3f134ea153aeba", null ],
    [ "WindowControllerPtr", "namespace_v_s_t_g_u_i_1_1_standalone.html#aebc7389ef9ee124d3a865503564a7832", null ],
    [ "WindowPtr", "namespace_v_s_t_g_u_i_1_1_standalone.html#a40ad0f557662f8ce0570f1e71de42bcd", null ],
    [ "AlertResult", "group__standalone.html#ga796a634e8a9576ab14040f1eca4a9f81", [
      [ "DefaultButton", "group__standalone.html#gga796a634e8a9576ab14040f1eca4a9f81a22b5e3ca27f5a966acd40ade16ea6033", null ],
      [ "SecondButton", "group__standalone.html#gga796a634e8a9576ab14040f1eca4a9f81a93fc595b2deae014255c4621f7c21231", null ],
      [ "ThirdButton", "group__standalone.html#gga796a634e8a9576ab14040f1eca4a9f81a520b8f34613e43a9243228e404519d64", null ],
      [ "Error", "group__standalone.html#gga796a634e8a9576ab14040f1eca4a9f81a902b0d55fddef6f8d651fe1035b7d4bd", null ]
    ] ],
    [ "CommonDirectoryLocation", "namespace_v_s_t_g_u_i_1_1_standalone.html#a85b0b2f6e6a60d5fe94fb12c07b55a1e", [
      [ "AppPath", "namespace_v_s_t_g_u_i_1_1_standalone.html#a85b0b2f6e6a60d5fe94fb12c07b55a1ea5b8378dd034570ab0edb0f2104f27feb", null ],
      [ "AppResourcesPath", "namespace_v_s_t_g_u_i_1_1_standalone.html#a85b0b2f6e6a60d5fe94fb12c07b55a1ea5d6b0a5c48f87fdc06a2bbe859637918", null ],
      [ "AppPreferencesPath", "namespace_v_s_t_g_u_i_1_1_standalone.html#a85b0b2f6e6a60d5fe94fb12c07b55a1ea2ab528e268974b603466458958ee6f2b", null ],
      [ "AppCachesPath", "namespace_v_s_t_g_u_i_1_1_standalone.html#a85b0b2f6e6a60d5fe94fb12c07b55a1eadf4d369a42e2798028ab29632ffaa849", null ],
      [ "UserDocumentsPath", "namespace_v_s_t_g_u_i_1_1_standalone.html#a85b0b2f6e6a60d5fe94fb12c07b55a1ea183d9fbaadc5976da90f0b41eae223de", null ]
    ] ],
    [ "WindowType", "group__standalone.html#ga476342970f954b62d70552bcbb5ee509", [
      [ "Document", "group__standalone.html#gga476342970f954b62d70552bcbb5ee509a0945359809dad1fbf3dea1c95a0da951", null ],
      [ "Popup", "group__standalone.html#gga476342970f954b62d70552bcbb5ee509a0d4c14a20b4d98a5de54e1480bf99a25", null ]
    ] ],
    [ "operator!=", "namespace_v_s_t_g_u_i_1_1_standalone.html#ac56f038028e91a83085da570187efedf", null ],
    [ "operator==", "namespace_v_s_t_g_u_i_1_1_standalone.html#adf9129bad413b750bc911d8317276db7", null ],
    [ "DefaultPreferencesGroupSeparator", "namespace_v_s_t_g_u_i_1_1_standalone.html#aa3f9a0d7b741e5548d8dc2eee49b4895", null ]
];